@@ -36,14 +36,14 @@ import glob
 import os
 import pickle
 import string
-from collections import OrderedDict, deque
+from collections import deque
 from typing import List, Optional, Tuple
 
 from libqtile import bar, hook, pangocffi, utils, xkeysyms
 from libqtile.backend.x11 import xcbq
-from libqtile.command_client import InteractiveCommandClient
-from libqtile.command_interface import CommandError, QtileCommandInterface
-from libqtile.command_object import CommandObject, SelectError
+from libqtile.command.base import CommandObject, SelectError
+from libqtile.command.client import InteractiveCommandClient
+from libqtile.command.interface import CommandError, QtileCommandInterface
 from libqtile.log_utils import logger
 from libqtile.widget import base
 
@@ -678,7 +678,7 @@ class Prompt(base._TextBox):
             pass
         d = Dummy()
         keysym = xcbq.keysyms[key]
-        d.detail = self.qtile.conn.keysym_to_keycode(keysym)
+        d.detail = self.qtile.conn.keysym_to_keycode(keysym)[0]
         d.state = 0
         self.handle_KeyPress(d)
 
@@ -746,10 +746,10 @@ class Prompt(base._TextBox):
         return deque(_LastUpdatedOrderedDict.fromkeys(dq))
 
 
-class _LastUpdatedOrderedDict(OrderedDict):
+class _LastUpdatedOrderedDict(dict):
     """Store items in the order the keys were last added."""
 
     def __setitem__(self, key, value):
         if key in self:
             del self[key]
-        OrderedDict.__setitem__(self, key, value)
+        super().__setitem__(key, value)
